{smcl}
{* 2013-05-01 scott long}{...}
{hi:help mchange}{right:also see: {helpb spost13}, {helpb margins}}
{hline}

{title:Changes in outcomes from regression models}


{p2colset 5 16 24 2}{...}
{p2col:{cmd:mchange} {hline 2}}Discrete and partial changes for regression models{p_end}
{p2colreset}{...}

{marker overview}
{title:Overview}

{pstd}
{cmd:mchange} uses {cmd:margins} and {cmd:predict} to compute partial
effects for independent variables in a regression model.
Marginal changes and discrete changes can be computed, with discrete
changes of one unit, a standard deviation,
0 to 1, the range, the trimmed range, or a specified amount.
Changes can be computed averaging over the sample known as average
marginal effects (AME). Changes holding
variables at specific values are possible with the
{cmd:atmeans} and {cmd:at()} options.
When possible, tests that the change is zero and confidence intervals
are computed.
Results are saved to matrices.
Some computations take a long time (e.g., average discrete changes
for {cmd:mlogit} with some variables held constant).

{cmd:mchange} works after a regression command supported by {cmd:margins} has
been run.


{title:General syntax}

{p 4 18 2}
{cmd:mchange }[{it:varlist}] [{it:if}] [{it:in}]{cmd:,} [ {it:options} ]
{p_end}

{p 8 10 2}
where {it:varlist} lists regressors for which changes are to be
computed. If no name is specified, changes for all independent variables
are computed.
{p_end}

    {help mchange##stats:Selecting statistics to compute}
    {help mchange##change:Selecting types of change}
    {help mchange##levels:Specifying values of regressors}
    {help mchange##output:Output options}
    {help mchange##matrices:Saved matrices}
    {help mchange##todo:To do list: things to add, test or fix}


{title:Options}
{marker stats}
{dlgtab:Statistics}
{pstd}

{pstd}
Various statistics can be computed for each change. By default only the
amount of change and the p-value of the test that the change is
0 are shown.
{p_end}
{p2colset 7 30 10 0}
{synopt:{opt stat:istics(stat-list)}}
specifies which statistics to compute for each change.
{cmd:stats()} is a synonym. By default only dc and the p-value
from the test that the change is 0 are displayed.
The statistics that can be computed are:

{p2colset 10 20 19 12}{...}
{p2col :Option}Statistic{p_end}
{p2line}
{p2col :{bf:change}}Discrete and marginal changes.{p_end}
{p2col :{bf:ul}}Upper level of CI.{p_end}
{p2col :{bf:ll}}Lower level of CI.{p_end}
{p2col :{bf:z}}z-value of test change is 0.{p_end}
{p2col :{bf:se}}Standard error of the estimated change.{p_end}
{p2col :{bf:pvalue}}p-value for test change is 0.{p_end}
{p2col :{bf:start}}Start value for discrete change.{p_end}
{p2col :{bf:end}}End value for discrete change.{p_end}
{p2line}
{p2colset 7 24 25 0}
{pstd}
The default level for the confidence interval is 95.
The level can be change with {helpb level:set level}.
{p_end}

{marker change}
{dlgtab:Types of changes}
{pstd}

{pstd}
By default for a change from 0 to 1 is computed for a binary
regressors.
For continuous variables changes of
one, a statndard deviation, and a marginal change (i.e., partial derivative)
are computed. These defaults can be changed using the following names for
amount of changes:
{p_end}
{p2colset 7 39 10 0}
{synopt:{opt amount(amount-list)}}Select one type of change to show
for continuous regressors. For example, {cmd:amount(one sd marginal)}.

{synopt:{opt amountb:inary(amount-list)}}
Select types of change to show for binary regressors.


{p2colset 10 20 20 12}{...}
{p2col :Option}Amount of change{p_end}
{p2line}
{p2col :{bf:range}}Change over range.{p_end}
{p2col :{bf:binary}}Change from 0 to 1.{p_end}
{p2col :{bf:one}}Change by 1 from observed value.{p_end}
{p2col :{bf:sd}}Change by the regressor's standard deviation
from the observed value. If {cmd:delta(delta-amount)} is used, a change of
{it:delta-amount} is computed. {cmd:amount(delta)} is a synonym for
{cmd:amount(sd)}.{p_end}
{p2col :{bf:marginal}}Marginal or instantaneous rate of change.{p_end}
{p2col :{bf:all}}All types of changes are computed.{p_end}
{p2line}

{synopt:{opt trim(#)}}
Instead of computing change over the range, trim this percentile from
each end of the distribution.

{synopt:{opt uncen:tered}}
Compute the change from the start value to a given among above the
start value (e.g., mean to mean+sd). By default the change would
be centered (e.g., mean-sd/2 to mean+sd/2).

{synopt:{opt delta(#)}}
Change by # units instead of standard deviation
(e.g., delta(4) computes a change of 4).
{p2line}

{marker levels}
{dlgtab:Setting values of variables when computing changes}
{pstd}

{pstd}
Predictions are computed using {cmd:margins}. Values at which
changes are computed are controlled with these options:
{p_end}
{p2colset 7 24 24 0}
{synopt:{opt at(atspec)}}
where {help margins##atspec:atspec} is set in the same way as with {cmd:margins}.
For example, at(wc=0 k5=0 age=50).

{synopt:{opt atmeans}}
Covariates held at their means unless
other values are specifed with {cmd:at()}. By default changes are computed
"asobserved" which is the default in {cmd:margins}.


{marker output}
{dlgtab:Controlling output}
{pstd}

{p2colset 7 24 25 0}
{synopt:{opt bystat:istic}}
For non-binary models show results with each type of statistics in its
own table (e.g., all the changes in one table; all the p-values in another).
Otherwise, results are organized by variable.

{synopt:{opt dec:imals(#)}}
Number of decimal digits to display.

{synopt:{opt title(title)}}
Label the output with this title.

{synopt:{opt brief}}
Do not show base values, values of r(at) matrix, or
details on how changes were computed.

{synopt:{opt verbose}}
Display the lengthy output from {cmd:margins} and {cmd:lincom} used
to compute the changes.

{synopt:{opt d:etails}}
Display the lengthy output from {cmd:margins} and {cmd:lincom} used
to compute the changes.

{marker matrices}
{dlgtab:Returned and saved matrices}
{pstd}

{p 5 5 2}
{ul:Matrices returned as r() returns}
{p_end}

{p2colset 10 28 28 12}{...}
{p2col :{marker matpostfix}Return name}Contents{p_end}
{p2line}
{p2col :{bf:table}}Single matrix with all results organized by variable.{p_end}
{p2col :{bf:change}}Changes.{p_end}
{p2col :{bf:end}}End value when computing discrete change.{p_end}
{p2col :{bf:ll}}Lower level of CI.{p_end}
{p2col :{bf:pvalue}}p-value for test change is 0.{p_end}
{p2col :{bf:se}}Standard error of the estimated change.{p_end}
{p2col :{bf:start}}Start value when computing discrete change.{p_end}
{p2col :{bf:ul}}Upper level of CI.{p_end}
{p2col :{bf:z}}z-value of test change is 0.{p_end}
{p2line}
{p2colset 7 24 25 0}

{p 5 5 2}
{ul:Matrices saved for {cmd:orplot} and {cmd:dcplot}}
{p_end}

{p2colset 10 33 27 12}{...}
{p2col :Matrices}Contents{p_end}
{p2line}
{p2col :{bf:_mchange_plot_dc}}Discrete and marginal changes.{p_end}
{p2col :{bf:_mchange_plot_pvalue}}p-value for test change is 0.{p_end}
{p2line}
{p2colset 7 24 25 0}

{title:Development work}
{marker todo}
{dlgtab:Things to do, test or debug}
    1. Is a margins passthrough needed?
    2. Add outcome() options for selecting outcomes.
    3. Verify that at() does not specify multiple levels such as at(wc=(0 1))


{title:Also see}

{pstd}
Manual: {hi:[M] matrix}

INCLUDE help spost13_footer
