*! version 0.5.4 2013-03-12 | freese long | add 'noconstant' and 'novary' option, allows margins, pwcompare
* version 0.5.3 2012-09-28 | freese long | list at values for varying matrix or nosplit option
* version 0.5.2 2012-09-20 | freese long | only as error if fatal
* version 0.5.1 2012-09-14 | freese long | first mlistat _return drop bug

** list at() matrix after margins

capture program drop mlistat
capture program drop _SplitAtMatrix

program define mlistat, sclass

    version 11.2

    syntax [anything(name=atmatrix)] , ///
        [   ///
        QUIetly /// only compute matrices; no printing
        omit  /// do not drop omitted and 0b columns
        ///
        ATvars(string asis)             /// select and rename r(at) variables
        ///
        COLEQnm(string asis)            /// add equation nm to output
        ROWEQnm(string asis)            /// add row nm to output
        ///
        DECimals(numlist >-1 integer)   /// digits when list matrix
        width(numlist >5 integer)       /// column widths
        ///
        NOSplit                         /// whether constant vs. varying at()
                                        /// are split out of output or not
        SAVEConstant(string) SAVEVarying(string) ///
		///
		NOConstant 						/// suppress printing of constant results
		NOVary							/// suppress printing of novary results
        ]

    tempname marginsret omitmat selectmat atConstant atVarying

//  trap errors

    local cmd = r(cmd)
    if `"`cmd'"'!="margins" & `"`cmd'"'!="pwcompare" {  
        if "`quietly'"=="" {
            display as error ///
            "mlistat must be run following margins"
        }
        sreturn local error "nomargins"
        error 999
    }

    local isat = 1
    capture confirm matrix r(at)
    local no_atreturn = _rc // no_atreturn==0 if r(at) is in memory
    if `no_atreturn' { // error if need at
        if "`quietly'"=="" {
            display _new ///
            "r(at) is not in memory to list"
        }
        sreturn local isat = 0
        sreturn local isvarying = 0
        sreturn local isconstant = 0
        sreturn local error "noat"
        error 999
     }

	capture _return drop `marginsret'
    _return hold `marginsret'
    _return restore `marginsret' , hold

//  parse optons

    * any table formatting implies split
    if  "`corder'"!=""    | "`rorder'"!=""   | "`coleqnm'"!="" ///
        | "`roweqnm'"!="" | "`decimals'"!="" | "`width'"!="" ///
        | "`title'"!="" {

        local split "nosplit"
    }

    local nosave = 0 // save matrix when done?
    if "`atmatrix'"=="" {
        local nosave = 1
        local atmatrix "_mlistat"
        capture matrix drop `atmatrix'
    }

    matrix `atmatrix' = r(at)

    if ("`decimals'"=="") local decimals = 3
    if ("`width'"=="") local width = 9

    local fmt "%`width'.`decimals'g"

    * omit collinear and base columns
    if "`omit'"=="" {

        tempname omitmat
        * remove b. columns from i. variables
        capture matrix drop `omitmat'
        local colnms : colnames `atmatrix'
        foreach icolnm of local colnms {
            local isbdot = 1 - regexm(`"`icolnm'"',"b\.")
            matrix `omitmat' = nullmat(`omitmat') , `isbdot'
        }
        _rm_matrix_select `atmatrix' `omitmat' col
        * omitted columns if any
        local colN = colsof(`atmatrix')
        _ms_omit_info `atmatrix' // find omitted names
        matrix `omitmat' = J(1,`colN',1) - r(omit)
        _rm_matrix_select `atmatrix' `omitmat' col

    }

//  select variables to list

    if "`atvars'"!="" {

        local atmat_colNM : colfullnames `atmatrix'
        _rm_matrix_rclist, rclist(`atvars') ///
                rcnames(`atmat_colNM') unab `quietly'

        if `r(error)'!=0 {
            _return restore `marginsret'
            exit
        }

        matrix `selectmat' = r(selectmat)
        _rm_matrix_select `atmatrix' `selectmat' col

    } // atvars() specified

//  change row values to row numbers

    local atmat_rowN = rowsof(`atmatrix')
    local atmat_rowNMS ""

    forvalues i = 1(1)`atmat_rowN' {
        local atmat_rowNMS "`atmat_rowNMS' `i'"
    }
    matrix rownames `atmatrix' = `atmat_rowNMS'

//  display at values

    if "`nosplit'" == "" {

         _SplitAtMatrix `atmatrix', title(`title')
        local isconstant = 0
        capture confirm matrix r(atConstant)
        if _rc == 0 {

            matrix `atConstant' = r(atConstant)
            local isconstant = 1

            if "`coleqnm'"!="" {
                matrix coleq `atConstant' = `coleqnm'
            }
            if "`roweqnm'"!="" {
                matrix roweq `atConstant' = `roweqnm'
            }

			if "`noconstant'" != "noconstant" {	
				local titleconstant "{bf}at() values held constant{sf}"
				matlist `atConstant', names(col) ///
					title("`titleconstant'") format("`fmt'")
			}		
        }

        local isvarying = 0
        capture confirm matrix r(atVarying)
        if _rc == 0 {

            local isvarying = 1
            matrix `atVarying' = r(atVarying)
            if "`coleqnm'"!="" {
                matrix coleq `atVarying' = `coleqnm'
            }
            if "`roweqnm'"!="" {
                matrix roweq `atVarying' = `roweqnm'
            }
			if "`novary'" != "novary" {	
				local titlevary "{bf}at() values vary{sf}"
				matlist `atVarying', rowtitle("_at") twidth(6) /// 
					title("`titlevary'") format("`fmt'") 
			}	
		}
    }
	
    //  no split

    else {

        if "`coleqnm'"!="" {
            matrix coleq `atmatrix' = `coleqnm'
        }
        if "`roweqnm'"!="" {
            matrix roweq `atmatrix' = `roweqnm'
        }

            matlist `atmatrix', rowtitle("_at") twidth(6) /// 
                title("`titlevary'") format("`fmt'") 

    }

//  save results if requested and returns

    sreturn local isat `isat'
    sreturn local isvarying `isvarying'
    sreturn local isconstant `isconstant'

    capture confirm matrix `atVarying'
    if _rc == 0 & "`savevarying'"!="" {
        matrix `savevarying' = `atVarying'
    }
    capture confirm matrix `atConstant'
    if _rc == 0 & "`saveconstant'"!="" {
        matrix `saveconstant' = `atConstant'
    }

    _return restore `marginsret'
    if `nosave' capture matrix drop `atmatrix'

end

program define _SplitAtMatrix, rclass

    return add

    syntax [anything] , [ title(string) ]

    tempname AtMatrix xVector Constant Varying

//  get r(at) and key facts about it

    matrix `AtMatrix' = `anything' // works with syntax specified in command

    local AtVariables : colnames `AtMatrix'
    local AtRowNames  : rownames `AtMatrix'
    local NAtColumns  = colsof(`AtMatrix')
    local NAtRows     = rowsof(`AtMatrix')

//  loop over all at variables

    forvalues i = 1(1)`NAtColumns' {

        * get name of variable and grab vector for that variable

        local xVariable : word `i' of `AtVariables'
        matrix `xVector' = `AtMatrix'[1..., `i']

       * loop over rows 1..k of at()
       * set IsConstant to FALSE if doesn't match row1

        local IsConstant "TRUE"
        forvalues i = 1(1)`NAtRows' {

            if `xVector'[`i',1] != `xVector'[1,1] {
                local IsConstant "FALSE"
            }
        }

//  check if missing and if so exclude

		local IsMissing "FALSE"
		if "`IsConstant'" == "TRUE" {
			if `xVector'[1,1] >= . {
				local IsMissing "TRUE"
			}
		}

//  add variable names / vector to constant or varying information

        if "`IsConstant'" == "TRUE" {
			if "`IsMissing'" == "FALSE" {
				local AtConstant "`xVariable' `AtConstant'"
				matrix `Constant' = (nullmat(`Constant'), `xVector')
			}
        }
        else {
            local AtVaries "`xVariable' `AtVaries'"
            matrix `Varying' = (nullmat(`Varying'), `xVector')
        }

    } // loop over at variables

//  return results

    capture confirm matrix `Constant'
    if _rc == 0 {
        matrix `Constant' = `Constant'[1,1...]
        return matrix atConstant = `Constant'
    }

    capture confirm matrix `Varying'
    if _rc == 0 {
        return matrix atVarying = `Varying'
    }

end // _SplitAtMatrix

exit

* version 0.1.0 sl
* version 0.1.1 2012-07-02 sl
* version 0.1.2 2012-07-26 jf splits at that constant from varies, all old functionality allowed with nosplit option
* version 0.1.3 2012-08-03 jf change to output
* version 0.1.4 2012-08-06 jf fix nosplit bug
* version 0.1.5 2012-08-07 jf error numbers and mlistat return
* version 0.1.6 2012-08-11 sl fixed title; remove di "_at";
    * returns s(error) instead of error exit for use as programming util
    * quietly suppresses error message
* version 0.2.0 2012-08-13 work on factor vars
* version 0.2.1 2012-08-20 use mlist1.ado not statout
* version 0.2.2 2012-08-21 fix variable selection; fix col/row eq; fv's work
* version 0.2.3 2012-08-21 add mp_atvars_parse.ado
* version 0.2.4 2012-08-21 add mp_atmat_colselect.ado
* version 0.2.5 2012-08-21 use mp_varlist_parse instead of atvars version
*   : use matrix name _mlistat_ to match other utilties
* version 0.2.6 2012-08-22 new utilties used
* version 0.2.8 2012-08-26 jsl | sreturn what matrices save | posted
    * isat isvarying isconstant
* version 0.2.7 2012-08-26 jsl | return matrices; make rclass | posted
    * Row of atConstant named "Constant" instead of "all"
    * constant vector transposed so smaller when printed
    * added SAVEConstant(string) SAVEVarying(string) to save matrices
* version 0.3.1 2012-09-01 jsl | atvars() selection added | posted
* version 0.3.0 2012-08-30 jsl | bug with atvars | posted
* version 0.2.9 2012-08-29 jf fixed bug with missing matrix values
	* FIXED BUG: atvars() option does not work
	*! BUG: choosing wc in factor variable syntax fails
* version 0.3.3 2012-09-04 | posted
    * remove 0b
    * remove mat name in output
    * make omit not noomit
    * remove corder and rorder and rowselect
    * use matlist for output
* version 0.3.2 2012-09-04 remove title() option | posted
* version 0.5.0 2012-09-14 jeremy freese scott long | first mlistat | posted
